@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: data_log.c 4265 2009-05-29 21:49:22Z roms $ */
+/* $Id: data_log.c 3053 2006-11-06 17:08:45Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -29,7 +29,6 @@
 #endif
 
 #include <glib.h>
-#include <glib/gstdio.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -43,27 +42,14 @@
 #include "log_hex.h"
 #include "log_dbus.h"
 #include "log_dusb.h"
-#include "log_nsp.h"
 
 int log_start(CableHandle *h)
 {
-	gchar *tmp;
-	
-	tmp = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, LOG_DIR, NULL);
-	g_mkdir(tmp, 0);
-	g_free(tmp);
-
 	log_hex_start();
-
 	if(h->model == CABLE_USB)
-	{
 		log_dusb_start();
-		log_nsp_start();
-	}
 	if(h->model != CABLE_USB)
-	{
 		log_dbus_start();
-	}
 
   	return 0;
 }
@@ -71,16 +57,10 @@ int log_start(CableHandle *h)
 int log_1(CableHandle *h, int dir, uint8_t data)
 {
 	log_hex_1(dir, data);
-
 	if(h->model == CABLE_USB)
-	{
 		log_dusb_1(dir, data);
-		log_nsp_1(dir, data);
-	}
 	if(h->model != CABLE_USB)
-	{
 		log_dbus_1(dir, data);
-	}
 
   	return 0;
 }
@@ -96,7 +76,6 @@ int log_N(CableHandle *h, int dir, uint8_t *data, int len)
 		log_hex_1(dir, data[i]);
 		log_dusb_1(dir, data[i]);
 		log_dbus_1(dir, data[i]);
-		log_nsp_1(dir, data[i]);
 	}
   	
   	return 0;
@@ -105,16 +84,10 @@ int log_N(CableHandle *h, int dir, uint8_t *data, int len)
 int log_stop(CableHandle *h)
 {
 	log_hex_stop();
-
 	if(h->model == CABLE_USB)
-	{
 		log_dusb_stop();
-		log_nsp_stop();
-	}
 	if(h->model != CABLE_USB)
-	{
 		log_dbus_stop();
-	}
 
   	return 0;
 }
