@@ -1,9 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: detect.c 4265 2009-05-29 21:49:22Z roms $ */
+/* $Id: detect.c 3081 2006-11-19 17:01:56Z kevinkofler $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
- *  Copyright (C) 2007  Kevin Kofler
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,7 +49,7 @@
 #  define IOCTL_TIUSB_GET_MAXPS      _IOR('N', 0x23, int) /* max packet size */
 # endif
 #endif
-#include <dirent.h>
+
 
 #include "../gettext.h"
 #include "../error.h"
@@ -218,17 +217,11 @@ static int check_for_node_usability(const char *pathname)
     }
     else 
     {
-	ticables_info(_("    node %s: does not exist"), pathname);
+	ticables_info(_("    node %s: does not exists"), pathname);
 	ticables_info(_("    => you will have to create the node."));
 	
 	return -1;
     }
-
-    if(!access(pathname, R_OK | W_OK))
-    {
-       ticables_info(_("    node %s: accessible"), pathname);
-       return 0;
-    }
     
     if(!stat(pathname, &st)) 
     {
@@ -245,24 +238,23 @@ static int check_for_node_usability(const char *pathname)
     
     if(getuid() == st.st_uid) 
     {
-	ticables_info(_("    user can r/w on device: yes"));
-	ticables_info(_("    => device is inaccessible for unknown reasons (SELinux?)"));
-    return -1;
+	ticables_info(_("    is user can r/w on device: yes"));
+	return 0;
     } 
     else 
     {
-	ticables_info(_("    user can r/w on device: no"));
+	ticables_info(_("    is user can r/w on device: no"));
     }
     
     if((st.st_mode & S_IROTH) && (st.st_mode & S_IWOTH))
     {
-	ticables_info(_("    others can r/w on device: yes"));
+	ticables_info(_("    are others can r/w on device: yes"));
     }
     else 
     {
 	char *user, *group;
 	
-	ticables_info(_("    others can r/w on device: no"));
+	ticables_info(_("    are others can r/w on device: no"));
 	
 	user = strdup(get_user_name(getuid()));
 	group = strdup(get_group_name(st.st_gid));
@@ -276,7 +268,7 @@ static int check_for_node_usability(const char *pathname)
 	{
 	    ticables_info(_("    is the user '%s' in the group '%s': no"), user, group);
 	    ticables_info(_("    => you should add your username at the group '%s' in '/etc/group'"), group);
-	    ticables_info(_("    => you will have to restart your session, too"));
+	    ticables_info(_("    => you will have to restart you session, too"), group);
 	    free(user); 
 	    free(group);
 	    
@@ -287,11 +279,10 @@ static int check_for_node_usability(const char *pathname)
 	free(group);
     }	
     
-	ticables_info(_("    => device is inaccessible for unknown reasons (SELinux?)"));
-    return -1;
+    return 0;
 }
 
-int linux_check_root(void)
+int check_for_root(void)
 {
     uid_t uid = getuid();
     
@@ -301,7 +292,7 @@ int linux_check_root(void)
     return (uid ? ERR_ROOT : 0);
 }
 
-int linux_check_tty(const char *devname)
+int check_for_tty(const char *devname)
 {
     struct serial_struct serinfo = { 0 };
     int fd;
@@ -349,7 +340,7 @@ int linux_check_tty(const char *devname)
     return 0;
 }
 
-int linux_check_parport(const char *devname)
+int check_for_parport(const char *devname)
 {
     int fd;
 
@@ -389,10 +380,10 @@ int linux_check_parport(const char *devname)
     return 0;
 }
 
-#define	USBFS	"/proc/bus/usb/"
-#define DEVFS    "/dev/bus/usb/"
+#define	USBFS	"/proc/bus/usb"
+#define DEVFS    "/dev/bus/usb"
 
-int linux_check_libusb(void)
+int check_for_libusb(void)
 {
 	ticables_info(_("Check for lib-usb support:"));
 #if defined(HAVE_LIBUSB)
@@ -403,40 +394,22 @@ int linux_check_libusb(void)
 #endif
 
     ticables_info(_("Check for lib-usb usability:"));
-
-    if(!access(DEVFS, F_OK))
+    
+    if(!access(USBFS, F_OK))
+    {
+	ticables_info(_("    usb filesystem (%s): %s"), USBFS, "mounted");
+    }
+    else if(!access(DEVFS, F_OK))
     {
 	ticables_info(_("    usb filesystem (%s): %s"), DEVFS, "mounted");
     }
-    else if(!access(USBFS, F_OK))
+    else 
     {
-      DIR* dir;
-      struct dirent *dirent;
-      int i;
-
-      dir = opendir(USBFS);
-      if(dir == NULL)
-	{
-	  ticables_info(_("    usb filesystem (%s): %s"), USBFS, "not mounted");
-	  return ERR_USBFS;
-	}
-      
-      for(i = 0; (dirent = readdir(dir)); i++);
-      closedir(dir);
-
-      if(i > 2)
-	ticables_info(_("    usb filesystem (%s): %s"), USBFS, "mounted");
-      else
-	{
-	  ticables_info(_("    usb filesystem (%s): %s"), USBFS, "not mounted");
-	  return ERR_USBFS;
-	}
-    }
-    else
-    {
-	ticables_info(_("    usb filesystem (/[proc|dev]/bus/usb): %s"), "not present");
-	ticables_info(_("    => you must have udev or usbfs support."));
-	ticables_info(_("    => take a look at the ticables2/CONFIG file."));
+	ticables_info(_("    usb filesystem (/proc|dev/bus/usb): %s"), "not mounted");
+	ticables_info(_("    => the usbfs must be supported by your kernel and you have to mount it"));
+	ticables_info(_("    => add a 'none /proc/bus/usb usbfs defaults 0 0' in your '/etc/fstab'."));
+	ticables_info(_("    => This line is enough for 'root' user. If you want to use it as a single user,"));
+	ticables_info(_("	 => take a look at the ticables2/README file."));
 	
 	return ERR_USBFS;
     }
@@ -444,7 +417,7 @@ int linux_check_libusb(void)
     return 0;
 }
 
-int linux_check_tiusb(const char *devname)
+int check_for_tiusb(const char *devname)
 {
     int fd;
     int arg;
@@ -471,7 +444,6 @@ int linux_check_tiusb(const char *devname)
 
     return 0;
 #else
-    fd = arg = -1;
     ticables_info(_("    tiusb support: not compiled."));
     return ERR_TTDEV;
 #endif
