@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: detect.h 3720 2007-08-24 20:57:50Z roms $ */
+/* $Id: detect.h 3053 2006-11-06 17:08:45Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -24,10 +24,10 @@
 
 #include <stdio.h>
 
-int linux_check_root(void);
-int linux_check_tty(const char *devname);
-int linux_check_parport(const char *devname);
-int linux_check_libusb(void);
-int linux_check_tiusb(const char *devname);
+int check_for_root(void);
+int check_for_tty(const char *devname);
+int check_for_parport(const char *devname);
+int check_for_libusb(void);
+int check_for_tiusb(const char *devname);
 
 #endif
