@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_gry.c 4244 2009-05-05 15:53:28Z kevinkofler $ */
+/* $Id: link_gry.c 3084 2006-11-26 09:07:10Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -59,7 +59,7 @@ static int gry_prepare(CableHandle *h)
 	}
 	h->priv2 = (struct termios *)calloc(1, sizeof(struct termios));
 
-	ret = linux_check_tty(h->device);
+	ret = check_for_tty(h->device);
 	if(ret)
 	{
 		free(h->device); h->device = NULL;
