@@ -35,16 +35,22 @@
 #include "logging.h"
 #include "data_log.h"
 
-#define HEX_FILE	"ticables-log.hex"
-#define LOG_FILE	"ticables-dbus.pkt"
+#define HEX_FILE	"ticables-hex.log"
+#define LOG_FILE	"ticables-dbus.log"
 
 static char *ifn = NULL;
 static char *ofn = NULL;
 
 int log_dbus_start(void)
 {
-	ifn = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, LOG_DIR, G_DIR_SEPARATOR_S, HEX_FILE, NULL);
-	ofn = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, LOG_DIR, G_DIR_SEPARATOR_S, LOG_FILE, NULL);
+  // build filenames
+#ifdef __WIN32__
+	ifn = g_strconcat("C:\\", HEX_FILE, NULL);
+	ofn = g_strconcat("C:\\", LOG_FILE, NULL);
+#else
+	ifn = g_strconcat(g_get_home_dir(), "/", HEX_FILE, NULL);
+	ofn = g_strconcat(g_get_home_dir(), "/", LOG_FILE, NULL);
+#endif
 
   	return 0;
 }
@@ -54,7 +60,7 @@ int log_dbus_1(int dir, uint8_t data)
   	return 0;
 }
 
-extern int dbus_decomp(const char *filename, int resync);
+extern int pkdecomp(const char *filename, int resync);
 
 int log_dbus_stop(void)
 {
@@ -66,7 +72,7 @@ int log_dbus_stop(void)
 	r = strrchr(ifn, '.');
 	if(r) *r = '\0';
 
-	dbus_decomp(ifn, 0);
+	pkdecomp(ifn, 0);	// ticables-hex.log -> ticables-hex.pkt
 	strcat(ifn, ".pkt");
 
 	g_unlink(ofn);
