@@ -34,19 +34,24 @@
 #include "data_log.h"
 #include "ticables.h"
 
-#define HEX_FILE	"ticables-log.hex"
+#define LOG_FILE  "ticables-hex.log"
 
 static char *fn = NULL;
 static FILE *log = NULL;
 
 int log_hex_start(void)
 {
-	fn = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, LOG_DIR, G_DIR_SEPARATOR_S, HEX_FILE, NULL);
+  // build filenames
+#ifdef __WIN32__
+	fn = g_strconcat("C:\\", LOG_FILE, NULL);
+#else
+	fn = g_strconcat(g_get_home_dir(), "/", LOG_FILE, NULL);
+#endif
 
   	log = fopen(fn, "wt");
   	if (log == NULL) 
 	{
-    		ticables_error("Unable to open %s for logging.\n", fn);
+    		ticables_error("Unable to open <%s> for logging.\n", fn);
     		return -1;
   	}
 
