@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ticables.c 4241 2009-05-03 13:38:29Z roms $ */
+/* $Id: ticables.c 3094 2006-12-07 17:38:34Z kevinkofler $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -33,11 +33,8 @@
 #ifdef __LINUX__
 #include <sys/utsname.h>
 #endif
-
-#ifdef _MSC_VER
-# include "./win32/usb.h"
-#elif defined(HAVE_LIBUSB)
-# include <usb.h>
+#if defined(HAVE_LIBUSB)
+#include <usb.h>
 #endif
 
 #include "gettext.h"
@@ -104,7 +101,7 @@ TIEXPORT1 int TICALL ticables_library_init(void)
   	HANDLE hDll;
   	int i;
 
-	hDll = GetModuleHandle("libticables2-2.dll");
+	hDll = GetModuleHandle("libticables2-1.dll");
   	GetModuleFileName(hDll, locale_dir, 65535);
 
   	for (i = strlen(locale_dir); i >= 0; i--) 
@@ -129,10 +126,10 @@ TIEXPORT1 int TICALL ticables_library_init(void)
   	errno = 0;
 
 #if defined(ENABLE_NLS)
-  	ticables_info("setlocale: %s", setlocale(LC_ALL, ""));
-  	ticables_info("bindtextdomain: %s", bindtextdomain(PACKAGE, locale_dir));
+  	ticables_info("setlocale: <%s>", setlocale(LC_ALL, ""));
+  	ticables_info("bindtextdomain: <%s>", bindtextdomain(PACKAGE, locale_dir));
   	//bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
-  	ticables_info("textdomain: %s", textdomain(PACKAGE));
+  	ticables_info("textdomain: <%s>", textdomain(PACKAGE));
 #endif
 #ifdef __LINUX__
 	{
