@@ -1,5 +1,5 @@
 /* Hey EMACS -*- win32-c -*- */
-/* $Id: detect.h 3720 2007-08-24 20:57:50Z roms $ */
+/* $Id: detect.h 3053 2006-11-06 17:08:45Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -26,13 +26,11 @@
 
 #define WIN_9X	1
 #define WIN_NT	2
-#define WIN_64	4
 
-int win32_check_os(void);
+int win32_detect_os(void);
 
-int win32_check_dha(void);
-int win32_check_rwp(void);
+int win32_detect_porttalk(void);
 
-int win32_check_libusb(void);
+int win32_detect_tiglusb(void);
 
 #endif
