@@ -1,5 +1,5 @@
 /* Hey EMACS -*- win32-c -*- */
-/* $Id: link_vti.c 4242 2009-05-03 14:06:55Z roms $ */
+/* $Id: link_vti.c 3053 2006-11-06 17:08:45Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -21,11 +21,6 @@
 
 /* "VTi" virtual link cable unit */
 
-/* 
- *  This unit uses two circular buffer implemented as shared memory.
- *  Names of shm are exchanged thru a messaging system.
- */
-
 #include <stdio.h>
 #include <assert.h>
 #include <windows.h>
@@ -68,10 +63,10 @@ static int vti_prepare(CableHandle *h)
 	case PORT_0:	// automatic setting
 		h->address = 1; h->device = strdup("TiLP"); 
 		break;
-	case PORT_1:	// reserved because used by VTi
+	case PORT_1:	// forced setting, for compat
 		h->address = 0; h->device = strdup("VTi"); 
 		break;
-	case PORT_2:	// 
+	case PORT_2: 
 		h->address = 1; h->device = strdup("TiLP"); 
 		break;
 	default: return ERR_ILLEGAL_ARG;
@@ -112,7 +107,7 @@ static int vti_open(CableHandle *h)
     /* Get the current DLL handle */
     Handle = GetModuleHandle("ticables2.dll");
 	if(!Handle)
-	  Handle = GetModuleHandle("libticables2-2.dll");
+	  Handle = GetModuleHandle("libticables2-0.dll");
   
     if (!Handle) 
     {
